==> Controlling-fabric-1.21.1-19.0.4-sources.jar: com/blamejared/controlling/platform/IPlatformHelper.java <==
package com.blamejared.controlling.platform;

import com.blamejared.controlling.client.NewKeyBindsScreen;
import com.blamejared.controlling.mixin.AccessKeyMapping;
import net.minecraft.class_156;
import net.minecraft.class_2561;
import net.minecraft.class_304;
import net.minecraft.class_315;
import net.minecraft.class_3675;

public interface IPlatformHelper {
    
    default boolean hasConflictingModifier(class_304 keybinding, class_304 other) {
        
        return false;
    }
    
    default void setKey(class_315 options, class_304 keybinding, class_3675.class_306 key) {
        
        options.method_1641(keybinding, key);
    }
    
    default void setToDefault(class_315 options, class_304 keybinding) {
        
        options.method_1641(keybinding, keybinding.method_1429());
    }
    
    default boolean isKeyCodeModifier(class_3675.class_306 key) {
        
        return false;
    }
    
    default class_2561 getKeyName(class_304 mapping) {
        
        return class_2561.method_43471(mapping.method_1431());
    }
    
    default void handleKeyPress(NewKeyBindsScreen screen, class_315 options, int key, int scancode, int mods) {
        
        if(screen.field_34799 != null) {
            if(key == 256) {
                Services.PLATFORM.setKey(options, screen.field_34799, class_3675.field_16237);
            } else {
                Services.PLATFORM.setKey(options, screen.field_34799, class_3675.method_15985(key, scancode));
            }
            if(!Services.PLATFORM.isKeyCodeModifier(((AccessKeyMapping) screen.field_34799).controlling$getKey())) {
                screen.field_34799 = null;
            }
            screen.field_34800 = class_156.method_658();
            screen.getKeyBindsList().method_49006();
        }
    }
    
}

==> Controlling-fabric-1.21.7-25.0.1-sources.jar: com/blamejared/controlling/platform/IPlatformHelper.java <==
package com.blamejared.controlling.platform;

import com.blamejared.controlling.client.NewKeyBindsScreen;
import com.blamejared.controlling.mixin.AccessKeyMapping;
import net.minecraft.class_156;
import net.minecraft.class_2561;
import net.minecraft.class_304;
import net.minecraft.class_315;
import net.minecraft.class_3675;

public interface IPlatformHelper {
    
    default boolean hasConflictingModifier(class_304 keybinding, class_304 other) {
        
        return false;
    }
    
    default void setKey(class_315 options, class_304 keybinding, class_3675.class_306 key) {
        
        keybinding.method_1422(key);
    }
    
    default void setToDefault(class_315 options, class_304 keybinding) {
        
        keybinding.method_1422(keybinding.method_1429());
    }
    
    default boolean isKeyCodeModifier(class_3675.class_306 key) {
        
        return false;
    }
    
    default class_2561 getKeyName(class_304 mapping) {
        
        return class_2561.method_43471(mapping.method_1431());
    }
    
    default void handleKeyPress(NewKeyBindsScreen screen, class_315 options, int key, int scancode, int mods) {
        
        if(screen.field_34799 != null) {
            if(key == 256) {
                Services.PLATFORM.setKey(options, screen.field_34799, class_3675.field_16237);
            } else {
                Services.PLATFORM.setKey(options, screen.field_34799, class_3675.method_15985(key, scancode));
            }
            if(!Services.PLATFORM.isKeyCodeModifier(((AccessKeyMapping) screen.field_34799).controlling$getKey())) {
                screen.field_34799 = null;
            }
            screen.field_34800 = class_156.method_658();
            screen.getKeyBindsList().method_49006();
        }
    }
    
    default boolean handleKeyReleased(NewKeyBindsScreen screen, class_315 options, int key, int scancode, int mods) {
        
        return false;
    }
    
}
